"""
This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
from PyKDE4 import plasmascript
from PyKDE4.plasma import Plasma
from PyKDE4.kdeui import KIcon, KMessageBox
import dbus


class PyRunnerDent(plasmascript.Runner):
  def init(self):
    # called upon creation to let us run initialization
    # tell the user how to use this runner
    print("init")
    self.addSyntax(Plasma.RunnerSyntax("dent :q:", "Quick Dent :q:"))
    self.sessionbus = dbus.SessionBus()
    #choqok bus is to post the message
    self.choqokbus = self.sessionbus.get_object("org.kde.choqok", "/")
    #globalaccel bus is to activate the post window
    self.accelbus = self.sessionbus.get_object("org.kde.kglobalaccel", 
           "/component/kwin")
    self.accelinterface = dbus.Interface(self.accelbus, 
         dbus_interface="org.kde.kglobalaccel.Component")
    self.activate_window_action = "Activate Window Demanding Attention"
    
    print(self.choqokbus)
    
  def match(self, context):
    #called by krunner to let us add actions for the user
    if not context.isValid():
      return
    
    #if choqokbus is not set then exit
    if self.choqokbus == None:
      return
    
    q = context.query()
    
    if not q.startsWith("dent "):
      return
      
    #ignore less than 3 characters after "msg "
    if q.length < 7:
      return
      
    #strip keyword and space
    q = q[4:].trimmed()
    
    #now create an action
    m = Plasma.QueryMatch(self.runner)
    m.setText("Quick Dent: '%s'" % q)
    m.setType(Plasma.QueryMatch.ExactMatch)
    m.setIcon(KIcon("laconica_microblog"))
    m.setData(q)
    context.addMatch(q, m)
    
  def run(self, context, match):
    # called when user selects our match
    self.choqokbus.postText(str(match.data().toString()))
    #KMessageBox.messageBox(None, KMessageBox.Information, match.data().toString())
    if self.accelinterface != None:
      self.accelinterface.invokeShortcut(self.activate_window_action)
    
def CreateRunner(parent):
  # called by krunner
  return PyRunnerDent(parent)
    
